@@ -1,7 +1,7 @@
-from dataclasses import dataclass, field
+from dataclasses import dataclass, field, fields
 from pathlib import Path
 from typing import Any, List, Optional, Tuple, Union
-import httpx
+from gdown import download
 from fasttext import FastText, load_model  # type: ignore
 from numpy import array
 from nptyping import NDArray
@@ -9,7 +9,7 @@ from nptyping import NDArray
 
 __MODEL_PATH = Path(__file__).parent / "models"
 __MODEL_FILE = __MODEL_PATH / "language.bin"  # lid.176.bim 128MB model
-__MODEL_URL = "https://dl.fbaipublicfiles.com/fasttext/supervised-models/lid.176.bin"
+__MODEL_URL = "https://drive.google.com/u/0/uc?id=1OC7C-eL31hoectGueYl6nfioANrZK2WI"
 
 
 def model_loader(*, model_url: str, re_download: Optional[bool] = False) -> None:
@@ -26,12 +26,7 @@ def model_loader(*, model_url: str, re_download: Optional[bool] = False) -> None
         # print(f"Downloading language model from {__MODEL_URL!r}. Runs only once!")
         __MODEL_PATH.mkdir(exist_ok=True)
 
-        timeout = httpx.Timeout(10.0, connect=60.0)
-        with httpx.Client(timeout=timeout) as client, __MODEL_FILE.open(
-            "wb"
-        ) as f_model:
-            model_content = client.get(model_url)
-            f_model.write(model_content.content)
+        download(url=model_url, output=__MODEL_FILE.as_posix(), quiet=True)
         # print("Downloading completed!")
 
 
@@ -62,7 +57,7 @@ class Language:
 
     @staticmethod
     def keys() -> List[str]:
-        return ["name", "score"]
+        return [field.name for field in fields(Language)]
 
     def __getitem__(self, key: str) -> Union[Any, str, float]:
         item = {"name": self.name, "score": self.score}
